<?php
////////////////////////////////////////////////////////////////////////
// Breeze Website Builder
// Copyright Silver Dolphin Solutions, LLC, Edward Lemmers, P.E.
// For licensing, see license.txt.
// Created: 3/1/2015	ELL

///////////////////////// Form Recipients /////////////////////////
// Buttons:
define('FORM_RECIPIENTS_HEADING', "Upraviť formulár Príjemcovia");
define('FORM_RECIPIENTS_EDIT_FORM_RECIPIENTS_BTN', "Upraviť formulár Príjemcovia");
// Console Text:
define('FORM_RECIPIENTS_FORM_PAGE', "formulár Page");
define('FORM_RECIPIENTS_MULTIPLE_RECIPIENTS_NOTE', "Môžete nastaviť viac ako jedného príjemcu oddelením e-maily s čiarkami.");
// Popup Messages:
define('FORM_RECIPIENTS_SAVING_RECIPIENT_MSG', "Ukladanie príjemcu ...");
define('VIEW_FORM_TABLES_HEADING', "Zobraziť tabuľky formulárov");
define('VIEW_FORM_TABLES_BTN', "Zobraziť tabuľky formulárov");
define('VIEW_FORM_TABLES_SELECT_TABLE', "Vyberte tabuľky na zobrazenie");
define('VIEW_FORM_TABLES_FILTER_READ', "Filtrovať správy");
?>